@@ -1,6 +1,6 @@
-import logging
 from copy import deepcopy
 from collections import defaultdict
+from t2wml.utils.debug_logging import basic_debug
 from t2wml.input_processing.region import YamlRegion
 import t2wml.utils.t2wml_exceptions as T2WMLExceptions
 from t2wml.parsing.t2wml_parsing import iter_on_n_for_code, T2WMLCode
@@ -78,8 +78,8 @@ class Node:
     def errors(self):
         return list(self._errors)
 
+    @basic_debug
     def validate(self):
-        logging.debug("enter Node validate")
         if t2wml_settings.no_wikification:
             return
         try:
@@ -134,7 +134,6 @@ class Node:
             self._errors.append(StatementError(field="property",
                                                message="Unsupported property type: "+property_type,
                                                qualifier=self.qualifier_index))
-        logging.debug("finished Node validate")
 
     def validate_datetime(self):
         try:
@@ -247,8 +246,8 @@ class NodeForEval(Node):
                 self.__dict__.pop(key)
         return cell_indices
 
+    @basic_debug
     def validate(self):
-        logging.debug("enter NodeForEval validate")
         # if it isn't already defined outside
         t_var_qcol = self.context.get("t_var_qcol", None)
         if t_var_qcol is None:
@@ -258,7 +257,6 @@ class NodeForEval(Node):
         for key in list(self.__dict__.keys()):
             self.parse_key(key)
         Node.validate(self)
-        logging.debug("exit NodeForEval validate")
 
     def serialize(self):
         return_dict = super().serialize()
@@ -272,8 +270,8 @@ class EvaluatedStatement(Statement, NodeForEval):
     def node_class(self):
         return NodeForEval
 
+    @basic_debug
     def _validate(self):
-        logging.debug("enter EvaluatedStatement _validate")
         try:
             subject = self.subject
         except AttributeError:
@@ -343,7 +341,6 @@ class EvaluatedStatement(Statement, NodeForEval):
                     self._errors.append((StatementError(field="reference",
                                                         message=str(e),
                                                         qualifier=False)))
-        logging.debug("exit EvaluatedStatement _validate")
 
 
     def validate(self):
