@@ -135,11 +135,11 @@ class ItemTable:
             t2wml_log.debug('Exited loop')
             if len(overwritten):
                 t2wml_log.debug("print count for overwritten")
-                print("Wikifier update overwrote existing values: "+str(overwritten))
+                ##print("Wikifier update overwrote existing values: "+str(overwritten))
             t2wml_log.debug('returning from function')
             return overwritten
         except Exception as e:
-            print(e)
+            #print(e)
             raise e
 
 
@@ -152,12 +152,12 @@ class Wikifier:
     def print_data(self):
         """prints a little summary of the contents of the wikifier
         """
-        print("The wikifier contains {} wiki files, and a total of {} dataframes".format(
+        #print("The wikifier contains {} wiki files, and a total of {} dataframes".format(
             len(self.wiki_files), len(self._data_frames)))
         if len(self.wiki_files):
-            print("The files are:")
+            #print("The files are:")
             for filename in self.wiki_files:
-                print(filename)
+                #print(filename)
 
     @property
     def item_table(self):
